@@ -1,27 +1,15 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "filteractionaddheader.h"
 
+#include <KComboBox>
 #include <KLineEdit>
 #include <KLocalizedString>
-#include <KComboBox>
 
 #include <QComboBox>
 #include <QHBoxLayout>
@@ -32,12 +20,8 @@ using namespace MailCommon;
 FilterActionAddHeader::FilterActionAddHeader(QObject *parent)
     : FilterActionWithStringList(QStringLiteral("add header"), i18n("Add Header"), parent)
 {
-    mParameterList << QString()
-                   << QStringLiteral("Reply-To")
-                   << QStringLiteral("Delivered-To")
-                   << QStringLiteral("X-KDE-PR-Message")
-                   << QStringLiteral("X-KDE-PR-Package")
-                   << QStringLiteral("X-KDE-PR-Keywords");
+    mParameterList << QString() << QStringLiteral("Reply-To") << QStringLiteral("Delivered-To") << QStringLiteral("X-KDE-PR-Message")
+                   << QStringLiteral("X-KDE-PR-Package") << QStringLiteral("X-KDE-PR-Keywords");
 
     mParameter = mParameterList.at(0);
 }
@@ -53,7 +37,7 @@ FilterAction::ReturnCode FilterActionAddHeader::process(ItemContext &context, bo
         return ErrorButGoOn;
     }
 
-    KMime::Message::Ptr msg = context.item().payload<KMime::Message::Ptr>();
+    auto msg = context.item().payload<KMime::Message::Ptr>();
 
     KMime::Headers::Base *header = KMime::Headers::createHeader(mParameter.toLatin1());
     if (!header) {
@@ -71,12 +55,12 @@ FilterAction::ReturnCode FilterActionAddHeader::process(ItemContext &context, bo
 
 QWidget *FilterActionAddHeader::createParamWidget(QWidget *parent) const
 {
-    QWidget *widget = new QWidget(parent);
-    QHBoxLayout *layout = new QHBoxLayout(widget);
+    auto widget = new QWidget(parent);
+    auto layout = new QHBoxLayout(widget);
     layout->setSpacing(4);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
-    KComboBox *comboBox = new KComboBox(widget);
+    auto comboBox = new KComboBox(widget);
     comboBox->setMinimumWidth(50);
     comboBox->setObjectName(QStringLiteral("combo"));
     comboBox->setEditable(true);
@@ -89,21 +73,20 @@ QWidget *FilterActionAddHeader::createParamWidget(QWidget *parent) const
 
     layout->addWidget(comboBox, 0 /* stretch */);
 
-    QLabel *label = new QLabel(i18n("With value:"), widget);
+    auto label = new QLabel(i18n("With value:"), widget);
     label->setObjectName(QStringLiteral("label_value"));
     label->setFixedWidth(label->sizeHint().width());
     layout->addWidget(label, 0);
 
-    KLineEdit *lineEdit = new KLineEdit(widget);
+    auto lineEdit = new KLineEdit(widget);
     lineEdit->setObjectName(QStringLiteral("ledit"));
     lineEdit->setTrapReturnKey(true);
     lineEdit->setClearButtonEnabled(true);
     layout->addWidget(lineEdit, 1);
 
     setParamWidgetValue(widget);
-    connect(comboBox, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &FilterActionAddHeader::filterActionModified);
-    connect(comboBox->lineEdit(), &QLineEdit::textChanged,
-            this, &FilterAction::filterActionModified);
+    connect(comboBox, &KComboBox::currentIndexChanged, this, &FilterActionAddHeader::filterActionModified);
+    connect(comboBox->lineEdit(), &QLineEdit::textChanged, this, &FilterAction::filterActionModified);
     connect(lineEdit, &QLineEdit::textChanged, this, &FilterActionAddHeader::filterActionModified);
 
     return widget;
@@ -125,7 +108,7 @@ void FilterActionAddHeader::setParamWidgetValue(QWidget *paramWidget) const
         comboBox->setCurrentIndex(index);
     }
 
-    QLineEdit *lineEdit = paramWidget->findChild<QLineEdit *>(QStringLiteral("ledit"));
+    auto *lineEdit = paramWidget->findChild<QLineEdit *>(QStringLiteral("ledit"));
     Q_ASSERT(lineEdit);
 
     lineEdit->setText(mValue);
@@ -148,7 +131,7 @@ void FilterActionAddHeader::clearParamWidget(QWidget *paramWidget) const
     Q_ASSERT(comboBox);
     comboBox->setCurrentIndex(0);
 
-    QLineEdit *lineEdit = paramWidget->findChild<QLineEdit *>(QStringLiteral("ledit"));
+    auto *lineEdit = paramWidget->findChild<QLineEdit *>(QStringLiteral("ledit"));
     Q_ASSERT(lineEdit);
     lineEdit->clear();
 }
@@ -177,11 +160,11 @@ void FilterActionAddHeader::argsFromString(const QString &argsStr)
     const QStringList list = argsStr.split(QLatin1Char('\t'));
     QString result;
     if (list.count() < 2) {
-        result = list[ 0 ];
+        result = list[0];
         mValue.clear();
     } else {
-        result = list[ 0 ];
-        mValue = list[ 1 ];
+        result = list[0];
+        mValue = list[1];
     }
 
     int index = mParameterList.indexOf(result);
