@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ public:
     static QString defaultFiltersSettingsPath();
 
 private:
-    Q_REQUIRED_RESULT QString createUniqFilterName();
+    Q_REQUIRED_RESULT MAILCOMMON_NO_EXPORT QString createUniqFilterName();
     void parseFilters(const QDomElement &e);
     int mFilterCount = 0;
 };
